@@ -166,6 +166,13 @@ class TypesBasicTests(ConnectingTestCase):
         curs.execute("select col from array_test where id = 2")
         self.assertEqual(curs.fetchone()[0], [])
 
+    @testutils.skip_before_postgres(8, 4)
+    def testNestedEmptyArray(self):
+        # issue #788
+        curs = self.conn.cursor()
+        curs.execute("select 10 = any(%s::int[])", ([[]], ))
+        self.assertFalse(curs.fetchone()[0])
+
     def testEmptyArrayNoCast(self):
         s = self.execute("SELECT '{}' AS foo")
         self.assertEqual(s, '{}')
@@ -502,7 +509,7 @@ class ByteaParserTest(unittest.TestCase):
         self.assertEqual(rv, b'')
 
     def test_full_hex(self, upper=False):
-        buf = ''.join(("%02x" % i) for i in list(range(256)))
+        buf = ''.join(("%02x" % i) for i in range(256))
         if upper:
             buf = buf.upper()
         buf = '\\x' + buf
@@ -516,7 +523,7 @@ class ByteaParserTest(unittest.TestCase):
         return self.test_full_hex(upper=True)
 
     def test_full_escaped_octal(self):
-        buf = ''.join(("\\%03o" % i) for i in list(range(256)))
+        buf = ''.join(("\\%03o" % i) for i in range(256))
         rv = self.cast(buf.encode('utf8'))
         if sys.version_info[0] < 3:
             self.assertEqual(rv, ''.join(map(chr, list(range(256)))))
@@ -525,7 +532,7 @@ class ByteaParserTest(unittest.TestCase):
 
     def test_escaped_mixed(self):
         import string
-        buf = ''.join(("\\%03o" % i) for i in list(range(32)))
+        buf = ''.join(("\\%03o" % i) for i in range(32))
         buf += string.ascii_letters
         buf += ''.join('\\' + c for c in string.ascii_letters)
         buf += '\\\\'
